@@ -14,10 +14,6 @@ User = get_user_model()
 class BaseCacheMixin:
     _cache_period: int = None
 
-    @property
-    def _cache_key(self):
-        return getattr(self._user, 'id')
-
     @property
     def _data_key(self):
         return self._point_id.id
@@ -25,7 +21,7 @@ class BaseCacheMixin:
     @property
     def _cache(self):
         if self._memory_cache is None:
-            all_cache_data = cache.get(self._cache_key)
+            all_cache_data = self.__get_cache()
             self._memory_cache = all_cache_data.get(self._data_key) if all_cache_data else None
             if os.getenv('IS_ENABLE_API_LOG') and self._memory_cache is not None:
                 print(f'GET REDIS {self}')
@@ -34,19 +30,19 @@ class BaseCacheMixin:
     @_cache.setter
     def _cache(self, value: any):
         if value is not None:
-            data = cache.get(self._cache_key)
+            data = self.__get_cache()
             ext_data = {f'{self._data_key}': value}
             data = dict(**data, **ext_data) if data else ext_data
-            cache.set(self._cache_key, data, self._cache_period)
+            self.__set_cache(data)
             self._memory_cache = value
 
     @log
     def flush_cache(self):
         """Delete Redis cache for current endpoint"""
-        data = cache.get(self._cache_key)
+        data = self.__get_cache()
         if data:
             data.pop(self._data_key, False)
-            cache.set(self._cache_key, data, self._cache_period)
+            self.__set_cache(data)
 
     def _get_related_points(self) -> list:
         """Set related points here"""
@@ -57,6 +53,19 @@ class BaseCacheMixin:
         for point in related_points:
             point.flush_cache()
 
+    def __set_cache(self, data):
+        cache.set(self.__cache_key, data, self._cache_period)
+
+    def __get_cache(self) -> Union[None, dict]:
+        try:
+            return cache.get(self.__cache_key)
+        except ModuleNotFoundError:
+            self.__set_cache(None)
+
+    @property
+    def __cache_key(self):
+        return getattr(self._user, 'id')
+
 
 class CacheMixin(BaseCacheMixin):
 
@@ -72,9 +81,10 @@ class CacheMixin(BaseCacheMixin):
 
     def _post(self, payload: dict):
         self._payload = payload
-        super()._post(payload)
+        response = super()._post(payload)
         self._memory_cache = None
         self._flush_cache_related_points()
+        return response
 
     def _post_file(self, file, file_name, type_):
         super()._post_file(file, file_name, type_)
