@@ -1,59 +1,14 @@
-__all__ = ('LoanPoint', 'PayPoint', 'ClosedLoanPoint')
+__all__ = ('LoanPoint', 'ClosedLoanPoint', 'LoanPaymentPoint')
 
 from typing import OrderedDict, Union
 
+
 from expressmoney.api import *
 
 SERVICE = 'loans'
 
 
-class LoanCreateContract(Contract):
-    sign = serializers.IntegerField()
-
-
-class LoanReadContract(LoanCreateContract):
-    OPEN = "OPEN"
-    OVERDUE = "OVERDUE"
-    STOP_INTEREST = "STOP_INTEREST"
-    DEFAULT = "DEFAULT"
-    CLOSED = "CLOSED"
-    STATUS_CHOICES = {
-        (OPEN, gettext_lazy("Open loan")),
-        (OVERDUE, gettext_lazy("Overdue loan")),
-        (STOP_INTEREST, gettext_lazy("Stop interest loan")),
-        (DEFAULT, gettext_lazy("Default loan")),
-        (CLOSED, gettext_lazy("Closed loan")),
-    }
-    OPEN_STATUSES = (OPEN, OVERDUE, STOP_INTEREST, DEFAULT)
-
-    pagination = PaginationContract()
-    id = serializers.IntegerField(min_value=1)
-    created = serializers.DateTimeField()
-    updated = serializers.DateTimeField()
-
-    amount = serializers.DecimalField(max_digits=7, decimal_places=0, allow_null=True)
-    period = serializers.IntegerField()
-    expiry_date = serializers.DateField()
-    expiry_period = serializers.IntegerField()
-
-    interests_charged_date = serializers.DateField(allow_null=True)
-    status = serializers.ChoiceField(choices=STATUS_CHOICES)
-
-    body_balance = serializers.DecimalField(max_digits=7, decimal_places=0, allow_null=True)
-    body_paid = serializers.DecimalField(max_digits=7, decimal_places=0, allow_null=True)
-    interests_total = serializers.DecimalField(max_digits=7, decimal_places=0, allow_null=True)
-    interests_paid = serializers.DecimalField(max_digits=7, decimal_places=0, allow_null=True)
-    interests_balance = serializers.DecimalField(max_digits=7, decimal_places=0)
-
-    document = serializers.CharField(max_length=256, allow_blank=True)
-    comment = serializers.CharField(max_length=2048, allow_blank=True)
-
-
-class PayUpdateContract(Contract):
-    bank_card_id = serializers.IntegerField()
-
-
-class ClosedLoanContract(Contract):
+class CommonLoan(Contract):
     OPEN = "OPEN"  # Customer received money
     OVERDUE = "OVERDUE"
     STOP_INTEREST = "STOP_INTEREST"
@@ -66,6 +21,7 @@ class ClosedLoanContract(Contract):
         (DEFAULT, "Default"),
         (CLOSED, "Closed")
     }
+    OPEN_STATUSES = (OPEN, OVERDUE, STOP_INTEREST, DEFAULT)
 
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
@@ -74,14 +30,16 @@ class ClosedLoanContract(Contract):
     interests_charged_date = serializers.DateField(allow_null=True)
     status = serializers.ChoiceField(choices=STATUS_CHOICES)
     sign = serializers.IntegerField()
-    ip = serializers.IPAddressField(protocol="IPv4")
+    ip = serializers.IPAddressField()
     document = serializers.CharField(max_length=256, allow_blank=True)
     comment = serializers.CharField(max_length=2048, allow_blank=True)
 
     amount = serializers.DecimalField(max_digits=16, decimal_places=0)
     period = serializers.IntegerField(min_value=0)
+    free_period = serializers.IntegerField(min_value=0)
+    interests = serializers.DecimalField(max_digits=3, decimal_places=2)
     expiry_date = serializers.DateField()
-    expiry_period = serializers.DateField()
+    expiry_period = serializers.IntegerField(min_value=0)
     body_balance = serializers.DecimalField(max_digits=16, decimal_places=0)
     body_paid = serializers.DecimalField(max_digits=16, decimal_places=0)
     interests_total = serializers.DecimalField(max_digits=16, decimal_places=0)
@@ -89,24 +47,66 @@ class ClosedLoanContract(Contract):
     interests_balance = serializers.DecimalField(max_digits=16, decimal_places=0)
 
 
+class LoanReadContract(CommonLoan):
+    pass
+
+
+class LoanCreateContract(Contract):
+    sign = serializers.IntegerField()
+
+
+class ClosedLoanContract(CommonLoan):
+    pass
+
+
+class LoanPaymentReadContract(Contract):
+    LOAN_BODY = 'LOAN_BODY'
+    LOAN_INTERESTS = 'LOAN_INTERESTS'
+    LOAN_ISSUE = 'LOAN_ISSUE'
+
+    TYPE_CHOICES = {
+        (LOAN_BODY, LOAN_BODY),
+        (LOAN_INTERESTS, LOAN_BODY),
+        (LOAN_ISSUE, LOAN_BODY),
+    }
+
+    id = serializers.IntegerField(min_value=1)
+    created = serializers.DateTimeField()
+    updated = serializers.DateTimeField()
+    loan = serializers.IntegerField(min_value=1)
+    type = serializers.ChoiceField(choices=TYPE_CHOICES)
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1)
+    bank_card_id = serializers.IntegerField(min_value=1)
+    bank_card_payment_id = serializers.IntegerField(min_value=1)
+
+
+class LoanPaymentCreateContract(Contract):
+    loan = serializers.IntegerField(min_value=1)
+    bank_card_id = serializers.IntegerField(min_value=1)
+
+
+class LoanPaymentResponseContract(LoanPaymentReadContract):
+    pass
+
+
 class LoanID(ID):
     _service = SERVICE
     _app = 'loans'
     _view_set = 'loan'
 
 
-class PayID(ID):
-    _service = SERVICE
-    _app = 'loans'
-    _view_set = 'pay'
-
-
 class ClosedLoanID(ID):
     _service = SERVICE
     _app = 'loans'
     _view_set = 'closed_loan'
 
 
+class LoanPaymentID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'loan_payment'
+
+
 class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = LoanID()
     _read_contract = LoanReadContract
@@ -120,11 +120,13 @@ class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
         return objects[-1] if len(objects) > 0 else None
 
 
-class PayPoint(UpdatePointMixin, ContractObjectPoint):
-    _point_id = PayID()
-    _update_contract = PayUpdateContract
-
-
 class ClosedLoanPoint(ListPointMixin, ContractPoint):
     _point_id = ClosedLoanID()
     _read_contract = ClosedLoanContract
+
+
+class LoanPaymentPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = LoanPaymentID()
+    _read_contract = LoanPaymentReadContract
+    _create_contract = LoanPaymentCreateContract
+    _response_contract = LoanPaymentResponseContract
