@@ -14,8 +14,14 @@ class GenericBankCard(Contract):
 
 
 class BankCardCreateContract(GenericBankCard):
-    ip = serializers.IPAddressField(allow_blank=True)
-    cryptogram = serializers.CharField(max_length=1024, allow_blank=True)
+    ip = serializers.IPAddressField()
+    cryptogram = serializers.CharField(max_length=1024)
+
+
+class BankCardResponseContract(BankCardCreateContract):
+    acs_url = serializers.URLField()
+    pa_req = serializers.CharField(max_length=1024)
+    md = serializers.CharField(max_length=1024)
 
 
 class BankCardReadContract(GenericBankCard):
@@ -51,6 +57,7 @@ class BankCard3dsID(ID):
 class BankCardPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = BankCardID()
     _create_contract = BankCardCreateContract
+    _response_contract = BankCardResponseContract
     _read_contract = BankCardReadContract
 
 
