@@ -9,7 +9,7 @@ SERVICE = 'profiles'
 class UserProfileCreateContract(Contract):
     user_id = serializers.IntegerField(min_value=1)
     department = serializers.IntegerField(min_value=1)
-    ip = serializers.IPAddressField(protocol='ipv4')
+    ip = serializers.IPAddressField()
     http_referer = serializers.URLField()
 
 
