@@ -1,4 +1,4 @@
-__all__ = ('OrderPoint',)
+__all__ = ('OrderScoringPoint',)
 
 from expressmoney.api import *
 
@@ -6,11 +6,11 @@ from expressmoney.api import *
 SERVICE = 'scoring'
 
 
-class OrderCreateContract(Contract):
+class OrderScoringCreateContract(Contract):
     order_id = serializers.IntegerField(min_value=1)
 
 
-class OrderReadContract(Contract):
+class OrderScoringReadContract(Contract):
     pagination = PaginationContract()
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
@@ -18,13 +18,13 @@ class OrderReadContract(Contract):
     order_id = serializers.IntegerField(min_value=1)
 
 
-class OrderID(ID):
+class OrderScoringID(ID):
     _service = SERVICE
     _app = 'credit_scoring'
-    _view_set = 'order'
+    _view_set = 'order_scoring'
 
 
-class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = OrderID()
-    _read_contract = OrderReadContract
-    _create_contract = OrderCreateContract
+class OrderScoringPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = OrderScoringID()
+    _read_contract = OrderScoringReadContract
+    _create_contract = OrderScoringCreateContract
